@@ -21,12 +21,6 @@
    :synopsis: Infrastructure-as-a-Service Cloud platform.
 """
 
-import six
-
 import gettext
 
-
-if six.PY2:
-    gettext.install('ec2api', unicode=1)
-else:
-    gettext.install('ec2api')
+gettext.install('ec2api')
