@@ -13,15 +13,14 @@
 # limitations under the License.
 
 import datetime
-import json
 import re
 
 from glanceclient.common import exceptions as glance_exception
 from lxml import etree
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-import six
 
 from ec2api import clients
 from ec2api.db import api as db_api
@@ -103,7 +102,7 @@ def dict_from_dotted_str(items):
     for key, value in items:
         parts = key.split(".")
         key = str(camelcase_to_underscore(parts[0]))
-        if isinstance(value, six.string_types):
+        if isinstance(value, str):
             # NOTE(vish): Automatically convert strings back
             #             into their respective values
             value = _try_convert(value)
@@ -146,10 +145,10 @@ def _render_data(el, data):
         el.text = str(data).lower()
     elif isinstance(data, datetime.datetime):
         el.text = _database_to_isoformat(data)
-    elif isinstance(data, six.binary_type):
+    elif isinstance(data, bytes):
         el.text = data.decode("utf-8")
     elif data is not None:
-        el.text = six.text_type(data)
+        el.text = str(data)
 
 
 def _database_to_isoformat(datetimeobj):
@@ -163,7 +162,7 @@ def dict_to_xml(data_dict, root_tag):
     return root
 
 
-_ms_time_regex = re.compile('^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3,6}Z$')
+_ms_time_regex = re.compile(r'^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d{3,6}Z$')
 
 
 def is_ec2_timestamp_expired(request, expires=None):
@@ -219,6 +218,7 @@ def change_ec2_id_kind(obj_id, new_kind):
     return '%(kind)s-%(id)s' % {'kind': new_kind,
                                 'id': obj_id.split('-')[-1]}
 
+
 NOT_FOUND_EXCEPTION_MAP = {
     'vpc': exception.InvalidVpcIDNotFound,
     'igw': exception.InvalidInternetGatewayIDNotFound,
@@ -373,7 +373,7 @@ def get_os_image(context, ec2_image_id):
 def deserialize_os_image_properties(os_image):
     def prepare_property(property_name):
         if property_name in os_image_dict:
-            os_image_dict[property_name] = json.loads(
+            os_image_dict[property_name] = jsonutils.loads(
                 os_image_dict[property_name])
 
     os_image_dict = dict(os_image)
@@ -502,9 +502,9 @@ def get_default_vpc(context):
 
 # NOTE(ft): following functions are copied from various parts of Nova
 
-_ephemeral = re.compile('^ephemeral(\d|[1-9]\d+)$')
+_ephemeral = re.compile(r'^ephemeral(\d|[1-9]\d+)$')
 
-_dev = re.compile('^/dev/')
+_dev = re.compile(r'^/dev/')
 
 
 def block_device_strip_dev(device_name):
