@@ -17,7 +17,6 @@ import copy
 
 import netaddr
 from novaclient import exceptions as nova_exception
-import six
 
 from ec2api.api import common
 from ec2api.api import ec2utils
@@ -596,7 +595,7 @@ def _get_active_route_destinations(context, route_table):
                     if (item['vpc_id'] == route_table['vpc_id'] and
                         (ec2utils.get_ec2_id_kind(item['id']) != 'vgw' or
                          item['id'] in vpn_connections))}
-    for vpn in six.itervalues(vpn_connections):
+    for vpn in vpn_connections.values():
         if vpn['vpn_gateway_id'] in destinations:
             destinations[vpn['vpn_gateway_id']]['vpn_connection'] = vpn
     return destinations
@@ -613,7 +612,7 @@ def _get_subnet_host_routes_and_gateway_ip(context, route_table, cidr_block,
         if 'gateway_id' in route:
             gateway_id = route['gateway_id']
             if gateway_id and gateway_id not in destinations:
-                    return '127.0.0.1'
+                return '127.0.0.1'
             return gateway_ip
         network_interface = destinations.get(route['network_interface_id'])
         if not network_interface:
