@@ -14,11 +14,13 @@
 
 import copy
 import itertools
+from unittest import mock
 
 from cinderclient import client as cinderclient
+import fixtures
 from glanceclient import client as glanceclient
-import mock
 from novaclient import client as novaclient
+from oslo_concurrency import lockutils
 from oslo_config import fixture as config_fixture
 from oslotest import base as test_base
 
@@ -56,7 +58,7 @@ def create_context(is_os_admin=False):
                if is_os_admin else
                mock.sentinel.session)
     session.get_endpoint = mock.Mock(name="get_endpoint")
-    session.get_endpoint.return_value = 'v2'
+    session.get_endpoint.return_value = 'v3'
     return ec2api.context.RequestContext(fakes.ID_OS_USER, fakes.ID_OS_PROJECT,
                                          is_os_admin=is_os_admin,
                                          session=session)
@@ -119,7 +121,7 @@ class MockOSMixin(object):
 
     def mock_cinder(self):
         cinder_patcher = mock.patch('cinderclient.client.Client')
-        cinder = mock.create_autospec(cinderclient.Client('2'))
+        cinder = mock.create_autospec(cinderclient.Client('3'))
         cinder_patcher.start().return_value = cinder
         self.addCleanup(cinder_patcher.stop)
         return cinder
@@ -160,6 +162,11 @@ class BaseTestCase(MockOSMixin, MockDBMixin, test_base.BaseTestCase):
         super(BaseTestCase, self).setUp()
         self._conf = self.useFixture(config_fixture.Config())
         self.configure(fatal_exception_format_errors=True)
+        lock_path = self.useFixture(fixtures.TempDir()).path
+        self.fixture = self.useFixture(
+            config_fixture.Config(lockutils.CONF))
+        self.fixture.config(lock_path=lock_path,
+                            group='oslo_concurrency')
 
     def configure(self, **kwargs):
         self._conf.config(**kwargs)
@@ -173,7 +180,7 @@ class ApiTestCase(BaseTestCase):
         super(ApiTestCase, self).setUp()
         self.mock_all_os()
         self.db_api = self.mock_db()
-        self.isotime = self.mock('oslo_utils.timeutils.isotime')
+        self.isotime = self.mock('ec2api.api.ec2utils.isotime')
 
     def execute(self, action, args):
         status_code, response = self._execute(action, args)
